@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -7,6 +8,7 @@ class ApiKey:
     default_attributes = {
         'id': None,     # int64 - API Key ID
         'descriptive_label': None,     # string - Unique label that describes this API key.  Useful for external systems where you may have API keys from multiple accounts and want a human-readable label for each key.
+        'description': None,     # string - User-supplied description of API key.
         'created_at': None,     # date-time - Time which API Key was created
         'expires_at': None,     # date-time - API Key expiration date
         'key': None,     # string - API Key actual key string
@@ -35,6 +37,7 @@ class ApiKey:
 
     # Parameters:
     #   name - string - Internal name for the API Key.  For your use.
+    #   description - string - User-supplied description of API key.
     #   expires_at - string - API Key expiration date
     #   permission_set - string - Permissions for this API Key.  Keys with the `desktop_app` permission set only have the ability to do the functions provided in our Desktop App (File and Share Link operations).  Additional permission sets may become available in the future, such as for a Site Admin to give a key with no administrator privileges.  If you have ideas for permission sets, please let us know.
     def update(self, params = None):
@@ -51,6 +54,8 @@ class ApiKey:
             raise InvalidParameterError("Bad parameter: id must be an int")
         if "name" in params and not isinstance(params["name"], str):
             raise InvalidParameterError("Bad parameter: name must be an str")
+        if "description" in params and not isinstance(params["description"], str):
+            raise InvalidParameterError("Bad parameter: description must be an str")
         if "expires_at" in params and not isinstance(params["expires_at"], str):
             raise InvalidParameterError("Bad parameter: expires_at must be an str")
         if "permission_set" in params and not isinstance(params["permission_set"], str):
@@ -85,15 +90,15 @@ class ApiKey:
 
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `expires_at`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `expires_at`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `expires_at`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `expires_at`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `expires_at`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `expires_at`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `expires_at`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `expires_at`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `expires_at`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `expires_at`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `expires_at`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `expires_at`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `expires_at`.
 def list(params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -124,18 +129,11 @@ def list(params = None, options = None):
 def all(params = None, options = None):
     list(params, options)
 
-# Parameters:
-#   format - string
-#   api_key - object
 def find_current(params = None, options = None):
     if not isinstance(params, dict):
         params = {}
     if not isinstance(options, dict):
         options = {}
-    if "format" in params and not isinstance(params["format"], str):
-        raise InvalidParameterError("Bad parameter: format must be an str")
-    if "api_key" in params and not isinstance(params["api_key"], dict):
-        raise InvalidParameterError("Bad parameter: api_key must be an dict")
     response, options = Api.send_request("GET", "/api_key", params, options)
     return ApiKey(response.data, options)
 
@@ -160,6 +158,7 @@ def get(id, params = None, options = None):
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
 #   name - string - Internal name for the API Key.  For your use.
+#   description - string - User-supplied description of API key.
 #   expires_at - string - API Key expiration date
 #   permission_set - string - Permissions for this API Key.  Keys with the `desktop_app` permission set only have the ability to do the functions provided in our Desktop App (File and Share Link operations).  Additional permission sets may become available in the future, such as for a Site Admin to give a key with no administrator privileges.  If you have ideas for permission sets, please let us know.
 #   path - string - Folder path restriction for this api key.
@@ -172,6 +171,8 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
     if "name" in params and not isinstance(params["name"], str):
         raise InvalidParameterError("Bad parameter: name must be an str")
+    if "description" in params and not isinstance(params["description"], str):
+        raise InvalidParameterError("Bad parameter: description must be an str")
     if "expires_at" in params and not isinstance(params["expires_at"], str):
         raise InvalidParameterError("Bad parameter: expires_at must be an str")
     if "permission_set" in params and not isinstance(params["permission_set"], str):
@@ -201,6 +202,7 @@ def update_current(params = None, options = None):
 
 # Parameters:
 #   name - string - Internal name for the API Key.  For your use.
+#   description - string - User-supplied description of API key.
 #   expires_at - string - API Key expiration date
 #   permission_set - string - Permissions for this API Key.  Keys with the `desktop_app` permission set only have the ability to do the functions provided in our Desktop App (File and Share Link operations).  Additional permission sets may become available in the future, such as for a Site Admin to give a key with no administrator privileges.  If you have ideas for permission sets, please let us know.
 def update(id, params = None, options = None):
@@ -213,6 +215,8 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: id must be an int")
     if "name" in params and not isinstance(params["name"], str):
         raise InvalidParameterError("Bad parameter: name must be an str")
+    if "description" in params and not isinstance(params["description"], str):
+        raise InvalidParameterError("Bad parameter: description must be an str")
     if "expires_at" in params and not isinstance(params["expires_at"], str):
         raise InvalidParameterError("Bad parameter: expires_at must be an str")
     if "permission_set" in params and not isinstance(params["permission_set"], str):
@@ -222,18 +226,11 @@ def update(id, params = None, options = None):
     response, options = Api.send_request("PATCH", "/api_keys/{id}".format(id=params['id']), params, options)
     return ApiKey(response.data, options)
 
-# Parameters:
-#   format - string
-#   api_key - object
 def delete_current(params = None, options = None):
     if not isinstance(params, dict):
         params = {}
     if not isinstance(options, dict):
         options = {}
-    if "format" in params and not isinstance(params["format"], str):
-        raise InvalidParameterError("Bad parameter: format must be an str")
-    if "api_key" in params and not isinstance(params["api_key"], dict):
-        raise InvalidParameterError("Bad parameter: api_key must be an dict")
     response, _options = Api.send_request("DELETE", "/api_key", params, options)
     return response.data
 
