@@ -11,6 +11,7 @@ class Folder:
         'display_name': None,     # string - File/Folder display name
         'type': None,     # string - Type: `directory` or `file`.
         'size': None,     # int64 - File/Folder size
+        'created_at': None,     # date-time - File created date/time
         'mtime': None,     # date-time - File last modified date/time, according to the server.  This is the timestamp of the last Files.com operation of the file, regardless of what modified timestamp was sent.
         'provided_mtime': None,     # date-time - File last modified date/time, according to the client who set it.  Files.com allows desktop, FTP, SFTP, and WebDAV clients to set modified at times.  This allows Desktop<->Cloud syncing to preserve modified at times.
         'crc32': None,     # string - File CRC32 checksum. This is sometimes delayed, so if you get a blank response, wait and try again.
@@ -52,7 +53,7 @@ class Folder:
 #   filter - string - If specified, will filter folders/files list by this string.  Wildcards of `*` and `?` are acceptable here.
 #   preview_size - string - Request a preview size.  Can be `small` (default), `large`, `xlarge`, or `pdf`.
 #   search - string - If `search_all` is `true`, provide the search string here.  Otherwise, this parameter acts like an alias of `filter`.
-#   search_all - boolean - Search entire site?
+#   search_all - boolean - Search entire site?  If set, we will ignore the folder path provided and search the entire site.  This is the same API used by the search bar in the UI.  Search results are a best effort, not real time, and not guaranteed to match every file.  This field should only be used for ad-hoc (human) searching, and not as part of an automated process.
 #   with_previews - boolean - Include file previews?
 #   with_priority_color - boolean - Include file priority color information?
 def list_for(path, params = None, options = None):
