@@ -14,6 +14,8 @@ class RemoteServer:
         'name': None,     # string - Internal name for your reference
         'port': None,     # int64 - Port for remote server.  Not needed for S3.
         'max_connections': None,     # int64 - Max number of parallel connections.  Ignored for S3 connections (we will parallelize these as much as possible).
+        'pin_to_site_region': None,     # boolean - If true, we will ensure that all communications with this remote server are made through the primary region of the site.  This setting can also be overridden by a sitewide setting which will force it to true.
+        'pinned_region': None,     # string - If set, all communciations with this remote server are made through the provided region.
         's3_bucket': None,     # string - S3 bucket name
         's3_region': None,     # string - S3 region
         'aws_access_key': None,     # string - AWS Access Key.
@@ -37,7 +39,11 @@ class RemoteServer:
         'auth_account_name': None,     # string - Describes the authorized account
         'one_drive_account_type': None,     # string - Either personal or business_other account types
         'azure_blob_storage_account': None,     # string - Azure Blob Storage Account name
+        'azure_blob_storage_sas_token': None,     # string - Shared Access Signature (SAS) token
         'azure_blob_storage_container': None,     # string - Azure Blob Storage Container name
+        'azure_files_storage_account': None,     # string - Azure File Storage Account name
+        'azure_files_storage_sas_token': None,     # string - Shared Access Signature (SAS) token
+        'azure_files_storage_share_name': None,     # string - Azure File Storage Share name
         's3_compatible_bucket': None,     # string - S3-compatible Bucket name
         's3_compatible_endpoint': None,     # string - S3-compatible endpoint
         's3_compatible_region': None,     # string - S3-compatible endpoint
@@ -46,6 +52,7 @@ class RemoteServer:
         'aws_secret_key': None,     # string - AWS secret key.
         'password': None,     # string - Password if needed.
         'private_key': None,     # string - Private key if needed.
+        'private_key_passphrase': None,     # string - Passphrase for private key if needed.
         'ssl_certificate': None,     # string - SSL client certificate.
         'google_cloud_storage_credentials_json': None,     # string - A JSON file that contains the private key. To generate see https://cloud.google.com/storage/docs/json_api/v1/how-tos/authorizing#APIKey
         'wasabi_secret_key': None,     # string - Wasabi secret key.
@@ -54,6 +61,7 @@ class RemoteServer:
         'rackspace_api_key': None,     # string - Rackspace API key from the Rackspace Cloud Control Panel.
         'reset_authentication': None,     # boolean - Reset authenticated account
         'azure_blob_storage_access_key': None,     # string - Azure Blob Storage secret key.
+        'azure_files_storage_access_key': None,     # string - Azure File Storage access key.
         's3_compatible_secret_key': None,     # string - S3-compatible secret key
     }
 
@@ -77,6 +85,7 @@ class RemoteServer:
     #   aws_secret_key - string - AWS secret key.
     #   password - string - Password if needed.
     #   private_key - string - Private key if needed.
+    #   private_key_passphrase - string - Passphrase for private key if needed.
     #   ssl_certificate - string - SSL client certificate.
     #   google_cloud_storage_credentials_json - string - A JSON file that contains the private key. To generate see https://cloud.google.com/storage/docs/json_api/v1/how-tos/authorizing#APIKey
     #   wasabi_access_key - string - Wasabi access key.
@@ -86,9 +95,11 @@ class RemoteServer:
     #   rackspace_api_key - string - Rackspace API key from the Rackspace Cloud Control Panel.
     #   reset_authentication - boolean - Reset authenticated account
     #   azure_blob_storage_access_key - string - Azure Blob Storage secret key.
+    #   azure_files_storage_access_key - string - Azure File Storage access key.
     #   hostname - string - Hostname or IP address
     #   name - string - Internal name for your reference
     #   max_connections - int64 - Max number of parallel connections.  Ignored for S3 connections (we will parallelize these as much as possible).
+    #   pin_to_site_region - boolean - If true, we will ensure that all communications with this remote server are made through the primary region of the site.  This setting can also be overridden by a sitewide setting which will force it to true.
     #   port - int64 - Port for remote server.  Not needed for S3.
     #   s3_bucket - string - S3 bucket name
     #   s3_region - string - S3 region
@@ -109,6 +120,10 @@ class RemoteServer:
     #   one_drive_account_type - string - Either personal or business_other account types
     #   azure_blob_storage_account - string - Azure Blob Storage Account name
     #   azure_blob_storage_container - string - Azure Blob Storage Container name
+    #   azure_blob_storage_sas_token - string - Shared Access Signature (SAS) token
+    #   azure_files_storage_account - string - Azure File Storage Account name
+    #   azure_files_storage_share_name - string - Azure File Storage Share name
+    #   azure_files_storage_sas_token - string - Shared Access Signature (SAS) token
     #   s3_compatible_bucket - string - S3-compatible Bucket name
     #   s3_compatible_endpoint - string - S3-compatible endpoint
     #   s3_compatible_region - string - S3-compatible endpoint
@@ -135,6 +150,8 @@ class RemoteServer:
             raise InvalidParameterError("Bad parameter: password must be an str")
         if "private_key" in params and not isinstance(params["private_key"], str):
             raise InvalidParameterError("Bad parameter: private_key must be an str")
+        if "private_key_passphrase" in params and not isinstance(params["private_key_passphrase"], str):
+            raise InvalidParameterError("Bad parameter: private_key_passphrase must be an str")
         if "ssl_certificate" in params and not isinstance(params["ssl_certificate"], str):
             raise InvalidParameterError("Bad parameter: ssl_certificate must be an str")
         if "google_cloud_storage_credentials_json" in params and not isinstance(params["google_cloud_storage_credentials_json"], str):
@@ -151,6 +168,8 @@ class RemoteServer:
             raise InvalidParameterError("Bad parameter: rackspace_api_key must be an str")
         if "azure_blob_storage_access_key" in params and not isinstance(params["azure_blob_storage_access_key"], str):
             raise InvalidParameterError("Bad parameter: azure_blob_storage_access_key must be an str")
+        if "azure_files_storage_access_key" in params and not isinstance(params["azure_files_storage_access_key"], str):
+            raise InvalidParameterError("Bad parameter: azure_files_storage_access_key must be an str")
         if "hostname" in params and not isinstance(params["hostname"], str):
             raise InvalidParameterError("Bad parameter: hostname must be an str")
         if "name" in params and not isinstance(params["name"], str):
@@ -197,6 +216,14 @@ class RemoteServer:
             raise InvalidParameterError("Bad parameter: azure_blob_storage_account must be an str")
         if "azure_blob_storage_container" in params and not isinstance(params["azure_blob_storage_container"], str):
             raise InvalidParameterError("Bad parameter: azure_blob_storage_container must be an str")
+        if "azure_blob_storage_sas_token" in params and not isinstance(params["azure_blob_storage_sas_token"], str):
+            raise InvalidParameterError("Bad parameter: azure_blob_storage_sas_token must be an str")
+        if "azure_files_storage_account" in params and not isinstance(params["azure_files_storage_account"], str):
+            raise InvalidParameterError("Bad parameter: azure_files_storage_account must be an str")
+        if "azure_files_storage_share_name" in params and not isinstance(params["azure_files_storage_share_name"], str):
+            raise InvalidParameterError("Bad parameter: azure_files_storage_share_name must be an str")
+        if "azure_files_storage_sas_token" in params and not isinstance(params["azure_files_storage_sas_token"], str):
+            raise InvalidParameterError("Bad parameter: azure_files_storage_sas_token must be an str")
         if "s3_compatible_bucket" in params and not isinstance(params["s3_compatible_bucket"], str):
             raise InvalidParameterError("Bad parameter: s3_compatible_bucket must be an str")
         if "s3_compatible_endpoint" in params and not isinstance(params["s3_compatible_endpoint"], str):
@@ -275,6 +302,7 @@ def get(id, params = None, options = None):
 #   aws_secret_key - string - AWS secret key.
 #   password - string - Password if needed.
 #   private_key - string - Private key if needed.
+#   private_key_passphrase - string - Passphrase for private key if needed.
 #   ssl_certificate - string - SSL client certificate.
 #   google_cloud_storage_credentials_json - string - A JSON file that contains the private key. To generate see https://cloud.google.com/storage/docs/json_api/v1/how-tos/authorizing#APIKey
 #   wasabi_access_key - string - Wasabi access key.
@@ -284,9 +312,11 @@ def get(id, params = None, options = None):
 #   rackspace_api_key - string - Rackspace API key from the Rackspace Cloud Control Panel.
 #   reset_authentication - boolean - Reset authenticated account
 #   azure_blob_storage_access_key - string - Azure Blob Storage secret key.
+#   azure_files_storage_access_key - string - Azure File Storage access key.
 #   hostname - string - Hostname or IP address
 #   name - string - Internal name for your reference
 #   max_connections - int64 - Max number of parallel connections.  Ignored for S3 connections (we will parallelize these as much as possible).
+#   pin_to_site_region - boolean - If true, we will ensure that all communications with this remote server are made through the primary region of the site.  This setting can also be overridden by a sitewide setting which will force it to true.
 #   port - int64 - Port for remote server.  Not needed for S3.
 #   s3_bucket - string - S3 bucket name
 #   s3_region - string - S3 region
@@ -307,6 +337,10 @@ def get(id, params = None, options = None):
 #   one_drive_account_type - string - Either personal or business_other account types
 #   azure_blob_storage_account - string - Azure Blob Storage Account name
 #   azure_blob_storage_container - string - Azure Blob Storage Container name
+#   azure_blob_storage_sas_token - string - Shared Access Signature (SAS) token
+#   azure_files_storage_account - string - Azure File Storage Account name
+#   azure_files_storage_share_name - string - Azure File Storage Share name
+#   azure_files_storage_sas_token - string - Shared Access Signature (SAS) token
 #   s3_compatible_bucket - string - S3-compatible Bucket name
 #   s3_compatible_endpoint - string - S3-compatible endpoint
 #   s3_compatible_region - string - S3-compatible endpoint
@@ -326,6 +360,8 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: password must be an str")
     if "private_key" in params and not isinstance(params["private_key"], str):
         raise InvalidParameterError("Bad parameter: private_key must be an str")
+    if "private_key_passphrase" in params and not isinstance(params["private_key_passphrase"], str):
+        raise InvalidParameterError("Bad parameter: private_key_passphrase must be an str")
     if "ssl_certificate" in params and not isinstance(params["ssl_certificate"], str):
         raise InvalidParameterError("Bad parameter: ssl_certificate must be an str")
     if "google_cloud_storage_credentials_json" in params and not isinstance(params["google_cloud_storage_credentials_json"], str):
@@ -342,6 +378,8 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: rackspace_api_key must be an str")
     if "azure_blob_storage_access_key" in params and not isinstance(params["azure_blob_storage_access_key"], str):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_access_key must be an str")
+    if "azure_files_storage_access_key" in params and not isinstance(params["azure_files_storage_access_key"], str):
+        raise InvalidParameterError("Bad parameter: azure_files_storage_access_key must be an str")
     if "hostname" in params and not isinstance(params["hostname"], str):
         raise InvalidParameterError("Bad parameter: hostname must be an str")
     if "name" in params and not isinstance(params["name"], str):
@@ -388,6 +426,14 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_account must be an str")
     if "azure_blob_storage_container" in params and not isinstance(params["azure_blob_storage_container"], str):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_container must be an str")
+    if "azure_blob_storage_sas_token" in params and not isinstance(params["azure_blob_storage_sas_token"], str):
+        raise InvalidParameterError("Bad parameter: azure_blob_storage_sas_token must be an str")
+    if "azure_files_storage_account" in params and not isinstance(params["azure_files_storage_account"], str):
+        raise InvalidParameterError("Bad parameter: azure_files_storage_account must be an str")
+    if "azure_files_storage_share_name" in params and not isinstance(params["azure_files_storage_share_name"], str):
+        raise InvalidParameterError("Bad parameter: azure_files_storage_share_name must be an str")
+    if "azure_files_storage_sas_token" in params and not isinstance(params["azure_files_storage_sas_token"], str):
+        raise InvalidParameterError("Bad parameter: azure_files_storage_sas_token must be an str")
     if "s3_compatible_bucket" in params and not isinstance(params["s3_compatible_bucket"], str):
         raise InvalidParameterError("Bad parameter: s3_compatible_bucket must be an str")
     if "s3_compatible_endpoint" in params and not isinstance(params["s3_compatible_endpoint"], str):
@@ -406,6 +452,7 @@ def create(params = None, options = None):
 #   aws_secret_key - string - AWS secret key.
 #   password - string - Password if needed.
 #   private_key - string - Private key if needed.
+#   private_key_passphrase - string - Passphrase for private key if needed.
 #   ssl_certificate - string - SSL client certificate.
 #   google_cloud_storage_credentials_json - string - A JSON file that contains the private key. To generate see https://cloud.google.com/storage/docs/json_api/v1/how-tos/authorizing#APIKey
 #   wasabi_access_key - string - Wasabi access key.
@@ -415,9 +462,11 @@ def create(params = None, options = None):
 #   rackspace_api_key - string - Rackspace API key from the Rackspace Cloud Control Panel.
 #   reset_authentication - boolean - Reset authenticated account
 #   azure_blob_storage_access_key - string - Azure Blob Storage secret key.
+#   azure_files_storage_access_key - string - Azure File Storage access key.
 #   hostname - string - Hostname or IP address
 #   name - string - Internal name for your reference
 #   max_connections - int64 - Max number of parallel connections.  Ignored for S3 connections (we will parallelize these as much as possible).
+#   pin_to_site_region - boolean - If true, we will ensure that all communications with this remote server are made through the primary region of the site.  This setting can also be overridden by a sitewide setting which will force it to true.
 #   port - int64 - Port for remote server.  Not needed for S3.
 #   s3_bucket - string - S3 bucket name
 #   s3_region - string - S3 region
@@ -438,6 +487,10 @@ def create(params = None, options = None):
 #   one_drive_account_type - string - Either personal or business_other account types
 #   azure_blob_storage_account - string - Azure Blob Storage Account name
 #   azure_blob_storage_container - string - Azure Blob Storage Container name
+#   azure_blob_storage_sas_token - string - Shared Access Signature (SAS) token
+#   azure_files_storage_account - string - Azure File Storage Account name
+#   azure_files_storage_share_name - string - Azure File Storage Share name
+#   azure_files_storage_sas_token - string - Shared Access Signature (SAS) token
 #   s3_compatible_bucket - string - S3-compatible Bucket name
 #   s3_compatible_endpoint - string - S3-compatible endpoint
 #   s3_compatible_region - string - S3-compatible endpoint
@@ -460,6 +513,8 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: password must be an str")
     if "private_key" in params and not isinstance(params["private_key"], str):
         raise InvalidParameterError("Bad parameter: private_key must be an str")
+    if "private_key_passphrase" in params and not isinstance(params["private_key_passphrase"], str):
+        raise InvalidParameterError("Bad parameter: private_key_passphrase must be an str")
     if "ssl_certificate" in params and not isinstance(params["ssl_certificate"], str):
         raise InvalidParameterError("Bad parameter: ssl_certificate must be an str")
     if "google_cloud_storage_credentials_json" in params and not isinstance(params["google_cloud_storage_credentials_json"], str):
@@ -476,6 +531,8 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: rackspace_api_key must be an str")
     if "azure_blob_storage_access_key" in params and not isinstance(params["azure_blob_storage_access_key"], str):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_access_key must be an str")
+    if "azure_files_storage_access_key" in params and not isinstance(params["azure_files_storage_access_key"], str):
+        raise InvalidParameterError("Bad parameter: azure_files_storage_access_key must be an str")
     if "hostname" in params and not isinstance(params["hostname"], str):
         raise InvalidParameterError("Bad parameter: hostname must be an str")
     if "name" in params and not isinstance(params["name"], str):
@@ -522,6 +579,14 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_account must be an str")
     if "azure_blob_storage_container" in params and not isinstance(params["azure_blob_storage_container"], str):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_container must be an str")
+    if "azure_blob_storage_sas_token" in params and not isinstance(params["azure_blob_storage_sas_token"], str):
+        raise InvalidParameterError("Bad parameter: azure_blob_storage_sas_token must be an str")
+    if "azure_files_storage_account" in params and not isinstance(params["azure_files_storage_account"], str):
+        raise InvalidParameterError("Bad parameter: azure_files_storage_account must be an str")
+    if "azure_files_storage_share_name" in params and not isinstance(params["azure_files_storage_share_name"], str):
+        raise InvalidParameterError("Bad parameter: azure_files_storage_share_name must be an str")
+    if "azure_files_storage_sas_token" in params and not isinstance(params["azure_files_storage_sas_token"], str):
+        raise InvalidParameterError("Bad parameter: azure_files_storage_sas_token must be an str")
     if "s3_compatible_bucket" in params and not isinstance(params["s3_compatible_bucket"], str):
         raise InvalidParameterError("Bad parameter: s3_compatible_bucket must be an str")
     if "s3_compatible_endpoint" in params and not isinstance(params["s3_compatible_endpoint"], str):
