@@ -12,6 +12,7 @@ class Site:
         'allowed_2fa_method_u2f': None,     # boolean - Is U2F two factor authentication allowed?
         'allowed_2fa_method_webauthn': None,     # boolean - Is WebAuthn two factor authentication allowed?
         'allowed_2fa_method_yubi': None,     # boolean - Is yubikey two factor authentication allowed?
+        'allowed_2fa_method_bypass_for_ftp_sftp_dav': None,     # boolean - Are users allowed to configure their two factor authentication to be bypassed for FTP/SFTP/WebDAV?
         'admin_user_id': None,     # int64 - User ID for the main site administrator
         'allow_bundle_names': None,     # boolean - Are manual Bundle names allowed?
         'allowed_countries': None,     # string - Comma seperated list of allowed Country codes
@@ -40,6 +41,7 @@ class Site:
         'mobile_app_session_ip_pinning': None,     # boolean - Is mobile app session IP pinning enabled?
         'mobile_app_session_lifetime': None,     # int64 - Mobile app session lifetime (in hours)
         'disallowed_countries': None,     # string - Comma seperated list of disallowed Country codes
+        'disable_files_certificate_generation': None,     # boolean - If set, Files.com will not set the CAA records required to generate future SSL certificates for this domain.
         'disable_notifications': None,     # boolean - Are notifications disabled?
         'disable_password_reset': None,     # boolean - Is password reset disabled?
         'domain': None,     # string - Custom domain
@@ -78,6 +80,9 @@ class Site:
         'login_help_text': None,     # string - Login help text
         'logo': None,     # Image - Branded logo
         'max_prior_passwords': None,     # int64 - Number of prior passwords to disallow
+        'motd_text': None,     # string - A message to show users when they connect via FTP or SFTP.
+        'motd_use_for_ftp': None,     # boolean - Show message to users connecting via FTP
+        'motd_use_for_sftp': None,     # boolean - Show message to users connecting via SFTP
         'next_billing_amount': None,     # double - Next billing amount
         'next_billing_date': None,     # string - Next billing date
         'office_integration_available': None,     # boolean - Allow users to use Office for the web?
@@ -95,6 +100,7 @@ class Site:
         'password_requirements_apply_to_bundles': None,     # boolean - Require bundles' passwords, and passwords for other items (inboxes, public shares, etc.) to conform to the same requirements as users' passwords?
         'password_validity_days': None,     # int64 - Number of days password is valid
         'phone': None,     # string - Site phone number
+        'pin_all_remote_servers_to_site_region': None,     # boolean - If true, we will ensure that all internal communications with any remote server are made through the primary region of the site. This setting overrides individual remote server settings.
         'require_2fa': None,     # boolean - Require two-factor authentication for all users?
         'require_2fa_stop_time': None,     # date-time - If set, requirement for two-factor authentication has been scheduled to end on this date-time.
         'require_2fa_user_type': None,     # string - What type of user is required to use two-factor authentication (when require_2fa is set to `true` for this site)?
@@ -127,6 +133,7 @@ class Site:
         'user_lockout_tries': None,     # int64 - Number of login tries within `user_lockout_within` hours before users are locked out
         'user_lockout_within': None,     # int64 - Number of hours for user lockout window
         'user_requests_enabled': None,     # boolean - Enable User Requests feature
+        'user_requests_notify_admins': None,     # boolean - Send email to site admins when a user request is received?
         'welcome_custom_text': None,     # string - Custom text send in user welcome email
         'welcome_email_cc': None,     # email - Include this email in welcome emails if enabled
         'welcome_email_subject': None,     # string - Include this email subject in welcome emails if enabled
@@ -197,10 +204,15 @@ def get_usage(params = None, options = None):
 #   folder_permissions_groups_only - boolean - If true, permissions for this site must be bound to a group (not a user). Otherwise, permissions must be bound to a user.
 #   welcome_screen - string - Does the welcome screen appear?
 #   office_integration_available - boolean - Allow users to use Office for the web?
+#   pin_all_remote_servers_to_site_region - boolean - If true, we will ensure that all internal communications with any remote server are made through the primary region of the site. This setting overrides individual remote server settings.
+#   motd_text - string - A message to show users when they connect via FTP or SFTP.
+#   motd_use_for_ftp - boolean - Show message to users connecting via FTP
+#   motd_use_for_sftp - boolean - Show message to users connecting via SFTP
 #   session_expiry - double - Session expiry in hours
 #   ssl_required - boolean - Is SSL required?  Disabling this is insecure.
 #   tls_disabled - boolean - Are Insecure TLS and SFTP Ciphers allowed?  Enabling this is insecure.
 #   sftp_insecure_ciphers - boolean - Are Insecure Ciphers allowed for SFTP?  Note:  Settting TLS Disabled -> True will always allow insecure ciphers for SFTP as well.  Enabling this is insecure.
+#   disable_files_certificate_generation - boolean - If set, Files.com will not set the CAA records required to generate future SSL certificates for this domain.
 #   user_lockout - boolean - Will users be locked out after incorrect login attempts?
 #   user_lockout_tries - int64 - Number of login tries within `user_lockout_within` hours before users are locked out
 #   user_lockout_within - int64 - Number of hours for user lockout window
@@ -233,13 +245,16 @@ def get_usage(params = None, options = None):
 #   non_sso_users_allowed - boolean - If true, users can be manually created / modified / deleted by Site Admins. Otherwise, users can only be managed via your SSO provider.
 #   sharing_enabled - boolean - Allow bundle creation
 #   user_requests_enabled - boolean - Enable User Requests feature
+#   user_requests_notify_admins - boolean - Send email to site admins when a user request is received?
 #   ftp_enabled - boolean - Is FTP enabled?
 #   sftp_enabled - boolean - Is SFTP enabled?
+#   bundle_watermark_value - object - Preview watermark settings applied to all bundle items. Uses the same keys as Behavior.value
 #   allowed_2fa_method_sms - boolean - Is SMS two factor authentication allowed?
 #   allowed_2fa_method_u2f - boolean - Is U2F two factor authentication allowed?
 #   allowed_2fa_method_totp - boolean - Is TOTP two factor authentication allowed?
 #   allowed_2fa_method_webauthn - boolean - Is WebAuthn two factor authentication allowed?
 #   allowed_2fa_method_yubi - boolean - Is yubikey two factor authentication allowed?
+#   allowed_2fa_method_bypass_for_ftp_sftp_dav - boolean - Are users allowed to configure their two factor authentication to be bypassed for FTP/SFTP/WebDAV?
 #   require_2fa - boolean - Require two-factor authentication for all users?
 #   require_2fa_user_type - string - What type of user is required to use two-factor authentication (when require_2fa is set to `true` for this site)?
 #   color2_top - string - Top bar background color
@@ -322,6 +337,8 @@ def update(params = None, options = None):
         raise InvalidParameterError("Bad parameter: mobile_app_session_lifetime must be an int")
     if "welcome_screen" in params and not isinstance(params["welcome_screen"], str):
         raise InvalidParameterError("Bad parameter: welcome_screen must be an str")
+    if "motd_text" in params and not isinstance(params["motd_text"], str):
+        raise InvalidParameterError("Bad parameter: motd_text must be an str")
     if "session_expiry" in params and not isinstance(params["session_expiry"], float):
         raise InvalidParameterError("Bad parameter: session_expiry must be an float")
     if "user_lockout_tries" in params and not isinstance(params["user_lockout_tries"], int):
@@ -346,6 +363,8 @@ def update(params = None, options = None):
         raise InvalidParameterError("Bad parameter: password_min_length must be an int")
     if "disable_users_from_inactivity_period_days" in params and not isinstance(params["disable_users_from_inactivity_period_days"], int):
         raise InvalidParameterError("Bad parameter: disable_users_from_inactivity_period_days must be an int")
+    if "bundle_watermark_value" in params and not isinstance(params["bundle_watermark_value"], dict):
+        raise InvalidParameterError("Bad parameter: bundle_watermark_value must be an dict")
     if "require_2fa_user_type" in params and not isinstance(params["require_2fa_user_type"], str):
         raise InvalidParameterError("Bad parameter: require_2fa_user_type must be an str")
     if "color2_top" in params and not isinstance(params["color2_top"], str):
